@@ -53,7 +53,10 @@ def generate_xlsx(object_list, REPORT, filename=False):
         class_name = obj.__class__.__name__
         if 'parameters' in REPORT:
             for attr in REPORT['parameters']:
-                data_inline.append(attrgetter(attr)(obj))
+                _value = attrgetter(attr)(obj)
+                if _value == None:
+                    _value = ''
+                data_inline.append(_value)
             data.append(data_inline)
     print(data)
 
