@@ -1,5 +1,6 @@
 from django.apps import apps
 from django.contrib.auth.decorators import login_required
+from django.db.models import Q
 from django.forms import formset_factory
 from django.http import HttpResponse, HttpResponseRedirect
 from django.shortcuts import get_object_or_404, render
@@ -388,7 +389,7 @@ def general_obj(request, Obj, ObjForm, general_obj_id, fields=(), \
 
 def general_obj_search(request, Obj, ObjForm, search_fields=(), \
         result_fields=(), template=False, allow_prompt_ajax_search=False, \
-        relational_obj_values={}, translations={}, \
+        allow_overall_search=False, relational_obj_values={}, translations={}, \
         import_instruction_for_obj=False, import_instruction_for_report=False, \
         *args, **kwargs):
     if not template:
@@ -403,6 +404,7 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
         ret_dic['passing_scripts'] = kwargs['passing_scripts']
     ret_dic['url_new'] = reverse('%s_new' % ret_dic['class_name'].lower())
     ret_dic['allow_prompt_ajax_search'] = allow_prompt_ajax_search
+    ret_dic['allow_overall_search'] = allow_overall_search
     ret_dic['import_instruction_for_obj'] = import_instruction_for_obj
     ret_dic['import_instruction_for_report'] = import_instruction_for_report
     return render(request, template, ret_dic)
@@ -410,68 +412,80 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
 
 def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
         result_fields=()):
+    is_overall_search = request.GET.get('is_overall_search', '')
     (fields, class_name, class_name_lower, ajax_url, charfield_exists, \
             datetimefield_exists, booleanfield_exists) = \
             get_params_for_search(request, Obj, ObjForm, search_fields, \
             result_fields)
+    print(request.GET)
     class_names_lower = '%ss' % class_name_lower
+    
 
     ret_dic = {}
     if not result_fields:
         result_fields = [field.name for field in Obj._meta.fields]
-    get_fields = {}
-    print(fields)
-    for field in fields:
-        if field[2] == 'ltgt':
-            get_fields['%s_gt' % field[0]] = request.GET.get(\
-                    '%s_gt' % field[0], '')
-            get_fields['%s_lt' % field[0]] = request.GET.get(\
-                    '%s_lt' % field[0], '')
-        elif field[2] == 'text':
-            get_fields[field[0]] = request.GET.get(field[0], '').strip()
-        elif field[2] == 'relation':
-            get_fields[field[0]] = \
-                    request.GET.get(field[0], '').strip().split(',')
-    print('gf = ', get_fields)
-    useful_data_available = False
-    useful_data_available = any([item[1] for item in get_fields.items()])
-    print('uf = ', useful_data_available)
-    if useful_data_available:
-        dt = {}
+
+    if is_overall_search:
+        overall_search = request.GET.get('overall_search', '')
+        q = Q()
         for field in fields:
-            if field[1] == 'number':
-                if get_fields['%s_gt' % field[0]]:
-                    dt['%s__gte' % field[0]] = get_fields['%s_gt' % field[0]]
-                if get_fields['%s_lt' % field[0]]:
-                    dt['%s__lte' % field[0]] = get_fields['%s_lt' % field[0]]
-            elif field[1] == 'text':
-                if get_fields[field[0]]:
-                    dt['%s__icontains' % field[0]] = \
-                            get_fields[field[0]].strip()
-            elif field[1] == 'date':
-                if get_fields['%s_gt' % field[0]]:
-                    dt['%s__gte' % field[0]] = datetime.datetime.strptime(\
-                            get_fields['%s_gt' % field[0]], '%d/%m/%Y')
-                if get_fields['%s_lt' % field[0]]:
-                    dt['%s__lte' % field[0]] = datetime.datetime.strptime(\
-                            get_fields['%s_lt' % field[0]], '%d/%m/%Y')
-            elif field[1] == 'boolean':
-                if get_fields[field[0]]:
-                    TRUE = 'true' in get_fields[field[0]].split(',')
-                    FALSE = 'false' in get_fields[field[0]].split(',')
-                    if TRUE and FALSE:
-                        pass
-                    elif TRUE:
-                        dt[field[0]] = True
-                    else:
-                        dt[field[0]] = False
-            elif field[1] == 'relation':
-                if any(get_fields[field[0]]):
-                    dt['%s__id__in' % field[0]] = get_fields[field[0]]
-        ret_dic['objects'] = Obj.objects.filter(**dt)
-        print('dt = %s' % dt)
+            if field[1] == 'text':
+                q = q|Q(("%s__icontains" % field[0], overall_search))
+        ret_dic['objects'] = Obj.objects.filter(q)
     else:
-        ret_dic['objects'] = Obj.objects.all()
+        get_fields = {}
+        print(fields)
+        for field in fields:
+            if field[2] == 'ltgt':
+                get_fields['%s_gt' % field[0]] = request.GET.get(\
+                        '%s_gt' % field[0], '')
+                get_fields['%s_lt' % field[0]] = request.GET.get(\
+                        '%s_lt' % field[0], '')
+            elif field[2] == 'text':
+                get_fields[field[0]] = request.GET.get(field[0], '').strip()
+            elif field[2] == 'relation':
+                get_fields[field[0]] = \
+                        request.GET.get(field[0], '').strip().split(',')
+        print('gf = ', get_fields)
+        useful_data_available = False
+        useful_data_available = any([item[1] for item in get_fields.items()])
+        print('uf = ', useful_data_available)
+        if useful_data_available:
+            dt = {}
+            for field in fields:
+                if field[1] == 'number':
+                    if get_fields['%s_gt' % field[0]]:
+                        dt['%s__gte' % field[0]] = get_fields['%s_gt' % field[0]]
+                    if get_fields['%s_lt' % field[0]]:
+                        dt['%s__lte' % field[0]] = get_fields['%s_lt' % field[0]]
+                elif field[1] == 'text':
+                    if get_fields[field[0]]:
+                        dt['%s__icontains' % field[0]] = \
+                                get_fields[field[0]].strip()
+                elif field[1] == 'date':
+                    if get_fields['%s_gt' % field[0]]:
+                        dt['%s__gte' % field[0]] = datetime.datetime.strptime(\
+                                get_fields['%s_gt' % field[0]], '%d/%m/%Y')
+                    if get_fields['%s_lt' % field[0]]:
+                        dt['%s__lte' % field[0]] = datetime.datetime.strptime(\
+                                get_fields['%s_lt' % field[0]], '%d/%m/%Y')
+                elif field[1] == 'boolean':
+                    if get_fields[field[0]]:
+                        TRUE = 'true' in get_fields[field[0]].split(',')
+                        FALSE = 'false' in get_fields[field[0]].split(',')
+                        if TRUE and FALSE:
+                            pass
+                        elif TRUE:
+                            dt[field[0]] = True
+                        else:
+                            dt[field[0]] = False
+                elif field[1] == 'relation':
+                    if any(get_fields[field[0]]):
+                        dt['%s__id__in' % field[0]] = get_fields[field[0]]
+            ret_dic['objects'] = Obj.objects.filter(**dt)
+            print('dt = %s' % dt)
+        else:
+            ret_dic['objects'] = Obj.objects.all()
     print(request.GET)
     ret_dic['all_id'] = ','.join([str(obj.id) for obj in \
             ret_dic['objects']])
